# ragged-stubs

![basedpyright](https://img.shields.io/badge/basedpyright-checked-42b983)
![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)
![uv](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/uv/main/assets/badge/v0.json)

Typing stubs for [ragged](https://pypi.org/project/ragged/).
